summaryrefslogtreecommitdiff
path: root/gcc/c-common.h
diff options
context:
space:
mode:
authorkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>2005-01-23 15:05:49 +0000
committerkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>2005-01-23 15:05:49 +0000
commit0975351bcd9c0a63d79206f725789009ad72bd3b (patch)
treea47662875339514cf8b46f25d1fe13a255cec8c2 /gcc/c-common.h
parent7b3423b968f7e45afe3d21fefefcae397065637e (diff)
downloadgcc-0975351bcd9c0a63d79206f725789009ad72bd3b.tar.gz
* alias.c, c-common.h, c-incpath.c, c-incpath.h, expr.c,
fold-const.c, gimplify.c, params.h, tree-data-ref.c, tree-if-conv.c, tree-nested.c, tree-outof-ssa.c, tree-ssa-dom.c, tree-vectorizer.c, tree.def, config/darwin.c, config/freebsd-spec.h, config/arm/arm.h, config/h8300/h8300.md, config/i386/i386.md, config/i386/predicates.md, config/i386/sse.md, config/ia64/ia64.c, config/ip2k/ip2k.c, config/s390/s390.c, config/vax/vax.md: Fix comment typos. Follow spelling conventions. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@94112 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/c-common.h')
-rw-r--r--gcc/c-common.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/gcc/c-common.h b/gcc/c-common.h
index 8ebc560169f..1a3f55103fc 100644
--- a/gcc/c-common.h
+++ b/gcc/c-common.h
@@ -1,6 +1,6 @@
/* Definitions for c-common.c.
Copyright (C) 1987, 1993, 1994, 1995, 1997, 1998,
- 1999, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+ 1999, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
This file is part of GCC.
@@ -241,7 +241,7 @@ extern c_language_kind c_language;
/* Information about a statement tree. */
struct stmt_tree_s GTY(()) {
/* The current statment list being collected. */
tree x_cur_stmt_list;
/* In C++, Nonzero if we should treat statements as full
@@ -272,9 +272,9 @@ struct c_language_function GTY(()) {
struct stmt_tree_s x_stmt_tree;
};
-/* When building a statement-tree, this is the current statment list
+/* When building a statement-tree, this is the current statement list
being collected. It's TREE_CHAIN is a back-pointer to the previous
- statment list. */
+ statement list. */
#define cur_stmt_list (current_stmt_tree ()->x_cur_stmt_list)
@@ -241,7 +241,7 @@ extern c_language_kind c_language;
/* Information about a statement tree. */
struct stmt_tree_s GTY(()) {
- /* The current statment list being collected. */
+ /* The current statement list being collected. */
tree x_cur_stmt_list;
/* In C++, Nonzero if we should treat statements as full